@@ -182,8 +182,8 @@ name                      class      transform    prior    trainable    shape
 SVGP.kernel.variance      Parameter  Softplus              True         ()       float64  1.0\n\
 SVGP.kernel.lengthscales  Parameter  Softplus              False        ()       float64  2.0\n\
 SVGP.likelihood.variance  Parameter  Softplus              True         ()       float64  1.0\n\
-SVGP.inducing_variable.Z  Parameter                        True         (10, 1)  float64  [[0.5...\n\
-SVGP.q_mu                 Parameter                        False        (10, 1)  float64  [[0....\n\
+SVGP.inducing_variable.Z  Parameter  Identity              True         (10, 1)  float64  [[0.5...\n\
+SVGP.q_mu                 Parameter  Identity              False        (10, 1)  float64  [[0....\n\
 SVGP.q_sqrt               Parameter  Softplus              True         (10, 1)  float64  [[1...."""
 
 example_tf_module_variable_print_string = """\
@@ -215,7 +215,7 @@ example_tf_keras_model = """\
 | C._trainable_weights[0] | ResourceVariable |             |         | True        | (2, 2, 1) | float32 | [[[0.... |\n\
 | C.variable              |                  |             |         |             |           |         |          |\n\
 +-------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
-| C.param                 | Parameter        |             |         | True        | ()        | float64 | 0.0      |\n\
+| C.param                 | Parameter        | Identity    |         | True        | ()        | float64 | 0.0      |\n\
 +-------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+"""
 
 # ------------------------------------------
@@ -254,7 +254,7 @@ def test_leaf_components_registers_variable_properties(module_callable, expected
     for path, variable in leaf_components(module).items():
         param_name = path.split(".")[-2] + "." + path.split(".")[-1]
         assert isinstance(variable, gpflow.Parameter)
-        np.testing.assert_equal(variable.value().numpy(), expected_param_dicts[param_name]["value"])
+        np.testing.assert_equal(variable.numpy(), expected_param_dicts[param_name]["value"])
         assert variable.trainable == expected_param_dicts[param_name]["trainable"]
         assert variable.shape == expected_param_dicts[param_name]["shape"]
 
@@ -272,7 +272,7 @@ def test_leaf_components_registers_compose_kernel_variable_properties(
         path_as_list = path.split(".")
         param_name = path_as_list[-3] + "." + path_as_list[-2] + "." + path_as_list[-1]
         assert isinstance(variable, gpflow.Parameter)
-        np.testing.assert_equal(variable.value().numpy(), expected_param_dicts[param_name]["value"])
+        np.testing.assert_equal(variable.numpy(), expected_param_dicts[param_name]["value"])
         assert variable.trainable == expected_param_dicts[param_name]["trainable"]
         assert variable.shape == expected_param_dicts[param_name]["shape"]
 
